[mpich-commits] [mpich] MPICH primary repository branch, master, updated. v3.2a2-39-ga4b5016

Service Account noreply at mpich.org
Tue Dec 9 17:29:41 CST 2014


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "MPICH primary repository".

The branch, master has been updated
       via  a4b5016f282fe2a1c4e6e81c4d3fc4f5c66e6de7 (commit)
      from  cae6aae24be0d5b075e29162682dc10976b6a67e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.mpich.org/mpich.git/commitdiff/a4b5016f282fe2a1c4e6e81c4d3fc4f5c66e6de7

commit a4b5016f282fe2a1c4e6e81c4d3fc4f5c66e6de7
Author: Charles J Archer <charles.j.archer at intel.com>
Date:   Tue Dec 9 15:04:56 2014 -0800

    Open Fabrics offical name is OFI rename from SFI

diff --git a/src/mpid/ch3/channels/nemesis/netmod/Makefile.mk b/src/mpid/ch3/channels/nemesis/netmod/Makefile.mk
index 648b7ee..c55c980 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/Makefile.mk
+++ b/src/mpid/ch3/channels/nemesis/netmod/Makefile.mk
@@ -13,4 +13,4 @@ include $(top_srcdir)/src/mpid/ch3/channels/nemesis/netmod/scif/Makefile.mk
 include $(top_srcdir)/src/mpid/ch3/channels/nemesis/netmod/portals4/Makefile.mk
 include $(top_srcdir)/src/mpid/ch3/channels/nemesis/netmod/ib/Makefile.mk
 include $(top_srcdir)/src/mpid/ch3/channels/nemesis/netmod/mxm/Makefile.mk
-include $(top_srcdir)/src/mpid/ch3/channels/nemesis/netmod/sfi/Makefile.mk
+include $(top_srcdir)/src/mpid/ch3/channels/nemesis/netmod/ofi/Makefile.mk
diff --git a/src/mpid/ch3/channels/nemesis/netmod/ofi/Makefile.mk b/src/mpid/ch3/channels/nemesis/netmod/ofi/Makefile.mk
new file mode 100644
index 0000000..0e19072
--- /dev/null
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/Makefile.mk
@@ -0,0 +1,19 @@
+## -*- Mode: Makefile; -*-
+## vim: set ft=automake :
+##
+## (C) 2011 by Argonne National Laboratory.
+##     See COPYRIGHT in top-level directory.
+##
+if BUILD_NEMESIS_NETMOD_SFI
+
+mpi_core_sources +=                                 		\
+    src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_init.c 	\
+    src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_cm.c	 	\
+    src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_tagged.c	\
+    src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_msg.c	 	\
+    src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_data.c	 	\
+    src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_progress.c
+
+errnames_txt_files += src/mpid/ch3/channels/nemesis/netmod/ofi/errnames.txt
+
+endif
diff --git a/src/mpid/ch3/channels/nemesis/netmod/ofi/errnames.txt b/src/mpid/ch3/channels/nemesis/netmod/ofi/errnames.txt
new file mode 100644
index 0000000..16c61b0
--- /dev/null
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/errnames.txt
@@ -0,0 +1,42 @@
+**ofi_avmap:SFI get address vector map failed
+**ofi_avmap %s %d %s %s:SFI address vector map failed (%s:%d:%s:%s)
+**ofi_tsend:SFI tagged sendto failed
+**ofi_tsend %s %d %s %s:SFI tagged sendto failed (%s:%d:%s:%s)
+**ofi_trecv:SFI tagged recvfrom failed
+**ofi_trecv %s %d %s %s:SFI tagged recvfrom failed (%s:%d:%s:%s)
+**ofi_getinfo:SFI getinfo() failed
+**ofi_getinfo %s %d %s %s:SFI getinfo() failed (%s:%d:%s:%s)
+**ofi_openep:SFI endpoint open failed
+**ofi_openep %s %d %s %s:SFI endpoint open failed (%s:%d:%s:%s)
+**ofi_openfabric:SFI fabric open failure
+**ofi_openfabric %s %d %s %s:SFI fabric open failed (%s:%d:%s:%s)
+**ofi_opendomain:SFI domain open failure
+**ofi_opendomain %s %d %s %s:SFI domain open failed (%s:%d:%s:%s)
+**ofi_opencq:SFI event queue create failure
+**ofi_opencq %s %d %s %s:SFI event queue create failed (%s:%d:%s:%s)
+**ofi_avopen:SFI address vector open failed
+**ofi_avopen %s %d %s %s:SFI address vector open failed (%s:%d:%s:%s)
+**ofi_bind:SFI resource bind failure
+**ofi_bind %s %d %s %s:SFI resource bind failed (%s:%d:%s:%s)
+**ofi_ep_enable:SFI endpoint enable failed
+**ofi_ep_enable %s %d %s %s:SFI endpoint enable failed (%s:%d:%s:%s)
+**ofi_getname:SFI get endpoint name failed
+**ofi_getname %s %d %s %s:SFI get endpoint name failed (%s:%d:%s:%s)
+**ofi_avclose:SFI av close failed
+**ofi_avclose %s %d %s %s:SFI av close failed (%s:%d:%s:%s)
+**ofi_epclose:SFI endpoint close failed
+**ofi_epclose %s %d %s %s:SFI endpoint close failed (%s:%d:%s:%s)
+**ofi_cqclose:SFI cq close failed
+**ofi_cqclose %s %d %s %s:SFI cq close failed (%s:%d:%s:%s)
+**ofi_mrclose:SFI mr close failed
+**ofi_mrclose %s %d %s %s:SFI mr close failed (%s:%d:%s:%s)
+**ofi_fabricclose:SFI fabric close failed
+**ofi_fabricclose %s %d %s %s:SFI fabric close failed (%s:%d:%s:%s)
+**ofi_domainclose:SFI domain close failed
+**ofi_domainclose %s %d %s %s:SFI domain close failed (%s:%d:%s:%s)
+**ofi_tsearch:SFI tsearch failed
+**ofi_tsearch %s %d %s %s:SFI tsearch failed (%s:%d:%s:%s)
+**ofi_poll:SFI poll failed
+**ofi_poll %s %d %s %s:SFI poll failed (%s:%d:%s:%s)
+**ofi_cancel:SFI cancel failed
+**ofi_cancel %s %d %s %s:SFI cancel failed (%s:%d:%s:%s)
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_cm.c b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_cm.c
similarity index 82%
rename from src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_cm.c
rename to src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_cm.c
index 54bf757..686a905 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_cm.c
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_cm.c
@@ -7,10 +7,10 @@
  *  to Argonne National Laboratory subject to Software Grant and Corporate
  *  Contributor License Agreement dated February 8, 2012.
  */
-#include "sfi_impl.h"
+#include "ofi_impl.h"
 
 /* ------------------------------------------------------------------------ */
-/* sfi_tag_to_vc                                                            */
+/* ofi_tag_to_vc                                                            */
 /* This routine converts tag information from an incoming preposted receive */
 /* into the VC that uses the routine.  There is a possibility of a small    */
 /* list of temporary VC's that are used during dynamic task management      */
@@ -21,8 +21,8 @@
 /* is enough to look up the VC.                                             */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(sfi_tag_to_vc)
-static inline MPIDI_VC_t *sfi_tag_to_vc(uint64_t match_bits)
+#define FCNAME DECL_FUNC(ofi_tag_to_vc)
+static inline MPIDI_VC_t *ofi_tag_to_vc(uint64_t match_bits)
 {
     int pgid = 0, port = 0;
     MPIDI_VC_t *vc = NULL;
@@ -70,7 +70,7 @@ static inline MPIDI_VC_t *sfi_tag_to_vc(uint64_t match_bits)
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_conn_req_callback                                           */
+/* MPID_nem_ofi_conn_req_callback                                           */
 /* A new process has been created and is connected to the current world     */
 /* The address of the new process is exchanged via the business card        */
 /* instead of being exchanged up front during the creation of the first     */
@@ -86,8 +86,8 @@ static inline MPIDI_VC_t *sfi_tag_to_vc(uint64_t match_bits)
 /* other VC's because they may not be part of a process group.              */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_conn_req_callback)
-static inline int MPID_nem_sfi_conn_req_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_conn_req_callback)
+static inline int MPID_nem_ofi_conn_req_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
 {
     int ret, len, mpi_errno = MPI_SUCCESS;
     char bc[SFI_KVSAPPSTRLEN];
@@ -108,7 +108,7 @@ static inline int MPID_nem_sfi_conn_req_callback(cq_tagged_entry_t * wc, MPID_Re
                        0,
                        MPID_CONN_REQ,
                        ~MPID_PROTOCOL_MASK,
-                       (void *) &(REQ_SFI(gl_data.conn_req)->sfi_context)), trecv);
+                       (void *) &(REQ_SFI(gl_data.conn_req)->ofi_context)), trecv);
 
     addr = MPIU_Malloc(gl_data.bound_addrlen);
     MPIU_Assertp(addr);
@@ -143,15 +143,15 @@ static inline int MPID_nem_sfi_conn_req_callback(cq_tagged_entry_t * wc, MPID_Re
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_handle_packet                                               */
+/* MPID_nem_ofi_handle_packet                                               */
 /* The "parent" request tracks the state of the entire rendezvous           */
 /* As "child" requests complete, the cc counter is decremented              */
 /* Notify CH3 that we have an incoming packet (if cc hits 1).  Otherwise    */
 /* decrement the ref counter via request completion                         */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_handle_packet)
-static inline int MPID_nem_sfi_handle_packet(cq_tagged_entry_t * wc ATTRIBUTE((unused)),
+#define FCNAME DECL_FUNC(MPID_nem_ofi_handle_packet)
+static inline int MPID_nem_ofi_handle_packet(cq_tagged_entry_t * wc ATTRIBUTE((unused)),
                                              MPID_Request * rreq)
 {
     int mpi_errno = MPI_SUCCESS;
@@ -169,24 +169,24 @@ static inline int MPID_nem_sfi_handle_packet(cq_tagged_entry_t * wc ATTRIBUTE((u
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_cts_send_callback                                           */
-/* A wrapper around MPID_nem_sfi_handle_packet that decrements              */
+/* MPID_nem_ofi_cts_send_callback                                           */
+/* A wrapper around MPID_nem_ofi_handle_packet that decrements              */
 /* the parent request's counter, and cleans up the CTS request              */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_cts_send_callback)
-static inline int MPID_nem_sfi_cts_send_callback(cq_tagged_entry_t * wc, MPID_Request * sreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_cts_send_callback)
+static inline int MPID_nem_ofi_cts_send_callback(cq_tagged_entry_t * wc, MPID_Request * sreq)
 {
     int mpi_errno = MPI_SUCCESS;
     BEGIN_FUNC(FCNAME);
-    MPI_RC(MPID_nem_sfi_handle_packet(wc, REQ_SFI(sreq)->parent));
+    MPI_RC(MPID_nem_ofi_handle_packet(wc, REQ_SFI(sreq)->parent));
     MPIDI_CH3U_Request_complete(sreq);
     END_FUNC_RC(FCNAME);
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_preposted_callback                                          */
-/* This callback handles incoming "SendContig" messages (see sfi_msg.c)     */
+/* MPID_nem_ofi_preposted_callback                                          */
+/* This callback handles incoming "SendContig" messages (see ofi_msg.c)     */
 /* for the send routines.  This implements the CTS response and the RTS     */
 /* handler.  The steps are as follows:                                      */
 /*   * Create a parent data request and post a receive into a pack buffer   */
@@ -194,8 +194,8 @@ static inline int MPID_nem_sfi_cts_send_callback(cq_tagged_entry_t * wc, MPID_Re
 /*   * Re-Post the RTS receive and handler to handle the next message       */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_preposted_callback)
-static inline int MPID_nem_sfi_preposted_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_preposted_callback)
+static inline int MPID_nem_ofi_preposted_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
 {
     int c, mpi_errno = MPI_SUCCESS;
     size_t pkt_len;
@@ -204,7 +204,7 @@ static inline int MPID_nem_sfi_preposted_callback(cq_tagged_entry_t * wc, MPID_R
     MPID_Request *new_rreq, *sreq;
     BEGIN_FUNC(FCNAME);
 
-    vc = sfi_tag_to_vc(wc->tag);
+    vc = ofi_tag_to_vc(wc->tag);
     MPIU_Assert(vc);
     VC_READY_CHECK(vc);
 
@@ -213,11 +213,11 @@ static inline int MPID_nem_sfi_preposted_callback(cq_tagged_entry_t * wc, MPID_R
     MPIU_ERR_CHKANDJUMP1(pack_buffer == NULL, mpi_errno, MPI_ERR_OTHER,
                          "**nomem", "**nomem %s", "Pack Buffer alloc");
     c = 1;
-    MPID_nem_sfi_create_req(&new_rreq, 1);
+    MPID_nem_ofi_create_req(&new_rreq, 1);
     MPID_cc_incr(new_rreq->cc_ptr, &c);
     new_rreq->dev.OnDataAvail = NULL;
     new_rreq->dev.next = NULL;
-    REQ_SFI(new_rreq)->event_callback = MPID_nem_sfi_handle_packet;
+    REQ_SFI(new_rreq)->event_callback = MPID_nem_ofi_handle_packet;
     REQ_SFI(new_rreq)->vc = vc;
     REQ_SFI(new_rreq)->pack_buffer = pack_buffer;
     REQ_SFI(new_rreq)->pack_buffer_size = pkt_len;
@@ -226,19 +226,19 @@ static inline int MPID_nem_sfi_preposted_callback(cq_tagged_entry_t * wc, MPID_R
                        REQ_SFI(new_rreq)->pack_buffer_size,
                        gl_data.mr,
                        VC_SFI(vc)->direct_addr,
-                       wc->tag | MPID_MSG_DATA, 0, &(REQ_SFI(new_rreq)->sfi_context)), trecv);
+                       wc->tag | MPID_MSG_DATA, 0, &(REQ_SFI(new_rreq)->ofi_context)), trecv);
 
-    MPID_nem_sfi_create_req(&sreq, 1);
+    MPID_nem_ofi_create_req(&sreq, 1);
     sreq->dev.OnDataAvail = NULL;
     sreq->dev.next = NULL;
-    REQ_SFI(sreq)->event_callback = MPID_nem_sfi_cts_send_callback;
+    REQ_SFI(sreq)->event_callback = MPID_nem_ofi_cts_send_callback;
     REQ_SFI(sreq)->parent = new_rreq;
     FI_RC(fi_tsend(gl_data.endpoint,
                      NULL,
                      0,
                      gl_data.mr,
                      VC_SFI(vc)->direct_addr,
-                     wc->tag | MPID_MSG_CTS, &(REQ_SFI(sreq)->sfi_context)), tsend);
+                     wc->tag | MPID_MSG_CTS, &(REQ_SFI(sreq)->ofi_context)), tsend);
     MPIU_Assert(gl_data.persistent_req == rreq);
 
     rreq->dev.user_count = 0;
@@ -248,17 +248,17 @@ static inline int MPID_nem_sfi_preposted_callback(cq_tagged_entry_t * wc, MPID_R
                        gl_data.mr,
                        0,
                        MPID_MSG_RTS,
-                       ~MPID_PROTOCOL_MASK, &(REQ_SFI(rreq)->sfi_context)), trecv);
+                       ~MPID_PROTOCOL_MASK, &(REQ_SFI(rreq)->ofi_context)), trecv);
     END_FUNC_RC(FCNAME);
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_connect_to_root_callback                                    */
+/* MPID_nem_ofi_connect_to_root_callback                                    */
 /* Complete and clean up the request                                        */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_connect_to_root_callback)
-int MPID_nem_sfi_connect_to_root_callback(cq_tagged_entry_t * wc ATTRIBUTE((unused)),
+#define FCNAME DECL_FUNC(MPID_nem_ofi_connect_to_root_callback)
+int MPID_nem_ofi_connect_to_root_callback(cq_tagged_entry_t * wc ATTRIBUTE((unused)),
                                           MPID_Request * sreq)
 {
     int mpi_errno = MPI_SUCCESS;
@@ -273,14 +273,14 @@ int MPID_nem_sfi_connect_to_root_callback(cq_tagged_entry_t * wc ATTRIBUTE((unus
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_cm_init                                                     */
+/* MPID_nem_ofi_cm_init                                                     */
 /* This is a utility routine that sets up persistent connection management  */
 /* requests and a persistent data request to handle rendezvous SendContig   */
 /* messages.                                                                */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_cm_init)
-int MPID_nem_sfi_cm_init(MPIDI_PG_t * pg_p, int pg_rank ATTRIBUTE((unused)))
+#define FCNAME DECL_FUNC(MPID_nem_ofi_cm_init)
+int MPID_nem_ofi_cm_init(MPIDI_PG_t * pg_p, int pg_rank ATTRIBUTE((unused)))
 {
     int mpi_errno = MPI_SUCCESS;
     MPID_Request *persistent_req, *conn_req;
@@ -289,20 +289,20 @@ int MPID_nem_sfi_cm_init(MPIDI_PG_t * pg_p, int pg_rank ATTRIBUTE((unused)))
     /* ------------------------------------- */
     /* Set up CH3 and netmod data structures */
     /* ------------------------------------- */
-    MPI_RC(MPIDI_CH3I_Register_anysource_notification(MPID_nem_sfi_anysource_posted,
-                                                      MPID_nem_sfi_anysource_matched));
-    MPIDI_Anysource_iprobe_fn = MPID_nem_sfi_anysource_iprobe;
-    MPIDI_Anysource_improbe_fn = MPID_nem_sfi_anysource_improbe;
+    MPI_RC(MPIDI_CH3I_Register_anysource_notification(MPID_nem_ofi_anysource_posted,
+                                                      MPID_nem_ofi_anysource_matched));
+    MPIDI_Anysource_iprobe_fn = MPID_nem_ofi_anysource_iprobe;
+    MPIDI_Anysource_improbe_fn = MPID_nem_ofi_anysource_improbe;
     gl_data.pg_p = pg_p;
 
     /* ----------------------------------- */
     /* Post a persistent request to handle */
     /* ----------------------------------- */
-    MPID_nem_sfi_create_req(&persistent_req, 1);
+    MPID_nem_ofi_create_req(&persistent_req, 1);
     persistent_req->dev.OnDataAvail = NULL;
     persistent_req->dev.next = NULL;
     REQ_SFI(persistent_req)->vc = NULL;
-    REQ_SFI(persistent_req)->event_callback = MPID_nem_sfi_preposted_callback;
+    REQ_SFI(persistent_req)->event_callback = MPID_nem_ofi_preposted_callback;
     FI_RC(fi_trecv(gl_data.endpoint,
                        &persistent_req->dev.user_count,
                        sizeof persistent_req->dev.user_count,
@@ -310,25 +310,25 @@ int MPID_nem_sfi_cm_init(MPIDI_PG_t * pg_p, int pg_rank ATTRIBUTE((unused)))
                        0,
                        MPID_MSG_RTS,
                        ~MPID_PROTOCOL_MASK,
-                       (void *) &(REQ_SFI(persistent_req)->sfi_context)), trecv);
+                       (void *) &(REQ_SFI(persistent_req)->ofi_context)), trecv);
     gl_data.persistent_req = persistent_req;
 
     /* --------------------------------- */
     /* Post recv for connection requests */
     /* --------------------------------- */
-    MPID_nem_sfi_create_req(&conn_req, 1);
+    MPID_nem_ofi_create_req(&conn_req, 1);
     conn_req->dev.user_buf = MPIU_Malloc(SFI_KVSAPPSTRLEN * sizeof(char));
     conn_req->dev.OnDataAvail = NULL;
     conn_req->dev.next = NULL;
     REQ_SFI(conn_req)->vc = NULL;       /* We don't know the source yet */
-    REQ_SFI(conn_req)->event_callback = MPID_nem_sfi_conn_req_callback;
+    REQ_SFI(conn_req)->event_callback = MPID_nem_ofi_conn_req_callback;
     FI_RC(fi_trecv(gl_data.endpoint,
                        conn_req->dev.user_buf,
                        SFI_KVSAPPSTRLEN,
                        gl_data.mr,
                        0,
                        MPID_CONN_REQ,
-                       ~MPID_PROTOCOL_MASK, (void *) &(REQ_SFI(conn_req)->sfi_context)), trecv);
+                       ~MPID_PROTOCOL_MASK, (void *) &(REQ_SFI(conn_req)->ofi_context)), trecv);
     gl_data.conn_req = conn_req;
 
 
@@ -341,22 +341,22 @@ int MPID_nem_sfi_cm_init(MPIDI_PG_t * pg_p, int pg_rank ATTRIBUTE((unused)))
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_cm_finalize                                                 */
+/* MPID_nem_ofi_cm_finalize                                                 */
 /* Clean up and cancle the requests initiated by the cm_init routine        */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_cm_finalize)
-int MPID_nem_sfi_cm_finalize()
+#define FCNAME DECL_FUNC(MPID_nem_ofi_cm_finalize)
+int MPID_nem_ofi_cm_finalize()
 {
     int mpi_errno = MPI_SUCCESS;
     BEGIN_FUNC(FCNAME);
     FI_RC(fi_cancel((fid_t) gl_data.endpoint,
-                    &(REQ_SFI(gl_data.persistent_req)->sfi_context)), cancel);
+                    &(REQ_SFI(gl_data.persistent_req)->ofi_context)), cancel);
     MPIR_STATUS_SET_CANCEL_BIT(gl_data.persistent_req->status, TRUE);
     MPIR_STATUS_SET_COUNT(gl_data.persistent_req->status, 0);
     MPIDI_CH3U_Request_complete(gl_data.persistent_req);
 
-    FI_RC(fi_cancel((fid_t) gl_data.endpoint, &(REQ_SFI(gl_data.conn_req)->sfi_context)), cancel);
+    FI_RC(fi_cancel((fid_t) gl_data.endpoint, &(REQ_SFI(gl_data.conn_req)->ofi_context)), cancel);
     MPIU_Free(gl_data.conn_req->dev.user_buf);
     MPIR_STATUS_SET_CANCEL_BIT(gl_data.conn_req->status, TRUE);
     MPIR_STATUS_SET_COUNT(gl_data.conn_req->status, 0);
@@ -369,15 +369,15 @@ int MPID_nem_sfi_cm_finalize()
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_vc_connect                                                  */
+/* MPID_nem_ofi_vc_connect                                                  */
 /* Handle CH3/Nemesis VC connections                                        */
 /*   * Query the VC address information.  In particular we are looking for  */
 /*     the fabric address name.                                             */
 /*   * Use fi_av_insert to register the address name with SFI               */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_vc_connect)
-int MPID_nem_sfi_vc_connect(MPIDI_VC_t * vc)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_vc_connect)
+int MPID_nem_ofi_vc_connect(MPIDI_VC_t * vc)
 {
     int len, ret, mpi_errno = MPI_SUCCESS;
     char bc[SFI_KVSAPPSTRLEN], *addr = NULL;
@@ -410,26 +410,26 @@ int MPID_nem_sfi_vc_connect(MPIDI_VC_t * vc)
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_vc_init)
-int MPID_nem_sfi_vc_init(MPIDI_VC_t * vc)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_vc_init)
+int MPID_nem_ofi_vc_init(MPIDI_VC_t * vc)
 {
     int mpi_errno = MPI_SUCCESS;
     MPIDI_CH3I_VC *const vc_ch = &vc->ch;
-    MPID_nem_sfi_vc_t *const vc_sfi = VC_SFI(vc);
+    MPID_nem_ofi_vc_t *const vc_ofi = VC_SFI(vc);
 
     BEGIN_FUNC(FCNAME);
-    vc->sendNoncontig_fn = MPID_nem_sfi_SendNoncontig;
-    vc_ch->iStartContigMsg = MPID_nem_sfi_iStartContigMsg;
-    vc_ch->iSendContig = MPID_nem_sfi_iSendContig;
+    vc->sendNoncontig_fn = MPID_nem_ofi_SendNoncontig;
+    vc_ch->iStartContigMsg = MPID_nem_ofi_iStartContigMsg;
+    vc_ch->iSendContig = MPID_nem_ofi_iSendContig;
     vc_ch->next = NULL;
     vc_ch->prev = NULL;
-    vc_sfi->is_cmvc = 0;
+    vc_ofi->is_cmvc = 0;
     vc->comm_ops = &_g_comm_ops;
 
     MPIDI_CHANGE_VC_STATE(vc, ACTIVE);
 
     if (NULL == vc->pg) {
-        vc_sfi->is_cmvc = 1;
+        vc_ofi->is_cmvc = 1;
     }
     else {
     }
@@ -438,13 +438,13 @@ int MPID_nem_sfi_vc_init(MPIDI_VC_t * vc)
 }
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_vc_destroy                                                  */
-/* MPID_nem_sfi_vc_terminate                                                */
+/* MPID_nem_ofi_vc_destroy                                                  */
+/* MPID_nem_ofi_vc_terminate                                                */
 /* TODO:  Verify this code has no leaks                                     */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_vc_destroy)
-int MPID_nem_sfi_vc_destroy(MPIDI_VC_t * vc)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_vc_destroy)
+int MPID_nem_ofi_vc_destroy(MPIDI_VC_t * vc)
 {
     BEGIN_FUNC(FCNAME);
     if (vc && (VC_SFI(vc)->is_cmvc == 1) && (VC_SFI(vc)->ready == 1)) {
@@ -471,8 +471,8 @@ int MPID_nem_sfi_vc_destroy(MPIDI_VC_t * vc)
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_vc_terminate)
-int MPID_nem_sfi_vc_terminate(MPIDI_VC_t * vc)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_vc_terminate)
+int MPID_nem_ofi_vc_terminate(MPIDI_VC_t * vc)
 {
     int mpi_errno = MPI_SUCCESS;
     BEGIN_FUNC(FCNAME);
@@ -484,7 +484,7 @@ int MPID_nem_sfi_vc_terminate(MPIDI_VC_t * vc)
 
 
 /* ------------------------------------------------------------------------ */
-/* MPID_nem_sfi_connect_to_root                                             */
+/* MPID_nem_ofi_connect_to_root                                             */
 /*  * A new unconnected VC (cm/ephemeral VC) has been created.  This code   */
 /*    connects the new VC to a rank in another process group.  The parent   */
 /*    address is obtained by an out of band method and given to this        */
@@ -499,7 +499,7 @@ int MPID_nem_sfi_vc_terminate(MPIDI_VC_t * vc)
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
 #define FCNAME DECL_FUNC(nm_connect_to_root)
-int MPID_nem_sfi_connect_to_root(const char *business_card, MPIDI_VC_t * new_vc)
+int MPID_nem_ofi_connect_to_root(const char *business_card, MPIDI_VC_t * new_vc)
 {
     int len, ret, mpi_errno = MPI_SUCCESS, str_errno = MPI_SUCCESS;
     int my_bc_len = SFI_KVSAPPSTRLEN;
@@ -527,14 +527,14 @@ int MPID_nem_sfi_connect_to_root(const char *business_card, MPIDI_VC_t * new_vc)
     VC_SFI(new_vc)->ready = 1;
     str_errno = MPIU_Str_add_int_arg(&bc, &my_bc_len, "tag", new_vc->port_name_tag);
     MPIU_ERR_CHKANDJUMP(str_errno, mpi_errno, MPI_ERR_OTHER, "**argstr_port_name_tag");
-    MPI_RC(MPID_nem_sfi_get_business_card(MPIR_Process.comm_world->rank, &bc, &my_bc_len));
+    MPI_RC(MPID_nem_ofi_get_business_card(MPIR_Process.comm_world->rank, &bc, &my_bc_len));
     my_bc_len = SFI_KVSAPPSTRLEN - my_bc_len;
 
-    MPID_nem_sfi_create_req(&sreq, 1);
+    MPID_nem_ofi_create_req(&sreq, 1);
     sreq->kind = MPID_REQUEST_SEND;
     sreq->dev.OnDataAvail = NULL;
     sreq->dev.next = NULL;
-    REQ_SFI(sreq)->event_callback = MPID_nem_sfi_connect_to_root_callback;
+    REQ_SFI(sreq)->event_callback = MPID_nem_ofi_connect_to_root_callback;
     REQ_SFI(sreq)->pack_buffer = my_bc;
     conn_req_send_bits = init_sendtag(0, MPIR_Process.comm_world->rank, 0, MPID_CONN_REQ);
     FI_RC(fi_tsend(gl_data.endpoint,
@@ -542,8 +542,8 @@ int MPID_nem_sfi_connect_to_root(const char *business_card, MPIDI_VC_t * new_vc)
                      my_bc_len,
                      gl_data.mr,
                      VC_SFI(new_vc)->direct_addr,
-                     conn_req_send_bits, &(REQ_SFI(sreq)->sfi_context)), tsend);
-    MPID_nem_sfi_poll(MPID_NONBLOCKING_POLL);
+                     conn_req_send_bits, &(REQ_SFI(sreq)->ofi_context)), tsend);
+    MPID_nem_ofi_poll(MPID_NONBLOCKING_POLL);
     VC_SFI(new_vc)->is_cmvc = 1;
     VC_SFI(new_vc)->next = gl_data.cm_vcs;
     gl_data.cm_vcs = new_vc;
@@ -559,8 +559,8 @@ int MPID_nem_sfi_connect_to_root(const char *business_card, MPIDI_VC_t * new_vc)
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_get_business_card)
-int MPID_nem_sfi_get_business_card(int my_rank ATTRIBUTE((unused)),
+#define FCNAME DECL_FUNC(MPID_nem_ofi_get_business_card)
+int MPID_nem_ofi_get_business_card(int my_rank ATTRIBUTE((unused)),
                                    char **bc_val_p, int *val_max_sz_p)
 {
     int mpi_errno = MPI_SUCCESS, str_errno = MPIU_STR_SUCCESS;
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_data.c b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_data.c
similarity index 51%
rename from src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_data.c
rename to src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_data.c
index 1e39684..d89270a 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_data.c
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_data.c
@@ -7,23 +7,23 @@
  *  to Argonne National Laboratory subject to Software Grant and Corporate
  *  Contributor License Agreement dated February 8, 2012.
  */
-#include "sfi_impl.h"
+#include "ofi_impl.h"
 
 
-MPID_nem_sfi_global_t gl_data;
+MPID_nem_ofi_global_t gl_data;
 
 /* ************************************************************************** */
 /* Netmod Function Table                                                      */
 /* ************************************************************************** */
 MPIDI_Comm_ops_t _g_comm_ops = {
-    MPID_nem_sfi_recv_posted,   /* recv_posted */
+    MPID_nem_ofi_recv_posted,   /* recv_posted */
 
-    MPID_nem_sfi_send,  /* send */
-    MPID_nem_sfi_send,  /* rsend */
-    MPID_nem_sfi_ssend, /* ssend */
-    MPID_nem_sfi_isend, /* isend */
-    MPID_nem_sfi_isend, /* irsend */
-    MPID_nem_sfi_issend,        /* issend */
+    MPID_nem_ofi_send,  /* send */
+    MPID_nem_ofi_send,  /* rsend */
+    MPID_nem_ofi_ssend, /* ssend */
+    MPID_nem_ofi_isend, /* isend */
+    MPID_nem_ofi_isend, /* irsend */
+    MPID_nem_ofi_issend,        /* issend */
 
     NULL,       /* send_init */
     NULL,       /* bsend_init */
@@ -31,28 +31,28 @@ MPIDI_Comm_ops_t _g_comm_ops = {
     NULL,       /* ssend_init */
     NULL,       /* startall */
 
-    MPID_nem_sfi_cancel_send,   /* cancel_send */
-    MPID_nem_sfi_cancel_recv,   /* cancel_recv */
+    MPID_nem_ofi_cancel_send,   /* cancel_send */
+    MPID_nem_ofi_cancel_recv,   /* cancel_recv */
 
     NULL,       /* probe */
-    MPID_nem_sfi_iprobe,        /* iprobe */
-    MPID_nem_sfi_improbe        /* improbe */
+    MPID_nem_ofi_iprobe,        /* iprobe */
+    MPID_nem_ofi_improbe        /* improbe */
 };
 
-MPID_nem_netmod_funcs_t MPIDI_nem_sfi_funcs = {
-    MPID_nem_sfi_init,
-    MPID_nem_sfi_finalize,
+MPID_nem_netmod_funcs_t MPIDI_nem_ofi_funcs = {
+    MPID_nem_ofi_init,
+    MPID_nem_ofi_finalize,
 #ifdef ENABLE_CHECKPOINTING
     NULL,
     NULL,
     NULL,
 #endif
-    MPID_nem_sfi_poll,
-    MPID_nem_sfi_get_business_card,
-    MPID_nem_sfi_connect_to_root,
-    MPID_nem_sfi_vc_init,
-    MPID_nem_sfi_vc_destroy,
-    MPID_nem_sfi_vc_terminate,
-    MPID_nem_sfi_anysource_iprobe,
-    MPID_nem_sfi_anysource_improbe,
+    MPID_nem_ofi_poll,
+    MPID_nem_ofi_get_business_card,
+    MPID_nem_ofi_connect_to_root,
+    MPID_nem_ofi_vc_init,
+    MPID_nem_ofi_vc_destroy,
+    MPID_nem_ofi_vc_terminate,
+    MPID_nem_ofi_anysource_iprobe,
+    MPID_nem_ofi_anysource_improbe,
 };
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_impl.h b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_impl.h
similarity index 83%
rename from src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_impl.h
rename to src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_impl.h
index d720170..553a5b7 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_impl.h
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_impl.h
@@ -54,7 +54,7 @@ typedef struct {
     MPID_Request *persistent_req;       /* Unexpected request queue    */
     MPID_Request *conn_req;     /* Connection request          */
     MPIDI_Comm_ops_t comm_ops;
-} MPID_nem_sfi_global_t;
+} MPID_nem_ofi_global_t;
 
 /* ******************************** */
 /* Device channel specific data     */
@@ -65,15 +65,15 @@ typedef struct {
     int ready;                  /* VC ready state     */
     int is_cmvc;                /* Cleanup VC         */
     MPIDI_VC_t *next;           /* VC queue           */
-} MPID_nem_sfi_vc_t;
-#define VC_SFI(vc) ((MPID_nem_sfi_vc_t *)vc->ch.netmod_area.padding)
+} MPID_nem_ofi_vc_t;
+#define VC_SFI(vc) ((MPID_nem_ofi_vc_t *)vc->ch.netmod_area.padding)
 
 /* ******************************** */
 /* Per request object data          */
 /* SFI/Netmod specific              */
 /* ******************************** */
 typedef struct {
-    context_t sfi_context;      /* Context Object              */
+    context_t ofi_context;      /* Context Object              */
     void *addr;                 /* SFI Address                 */
     event_callback_fn event_callback;   /* Callback Event              */
     char *pack_buffer;          /* MPI Pack Buffer             */
@@ -83,8 +83,8 @@ typedef struct {
     MPIDI_VC_t *vc;             /* VC paired with this request */
     uint64_t tag;               /* 64 bit tag request          */
     MPID_Request *parent;       /* Parent request              */
-} MPID_nem_sfi_req_t;
-#define REQ_SFI(req) ((MPID_nem_sfi_req_t *)((req)->ch.netmod_area.padding))
+} MPID_nem_ofi_req_t;
+#define REQ_SFI(req) ((MPID_nem_ofi_req_t *)((req)->ch.netmod_area.padding))
 
 /* ******************************** */
 /* Logging and function macros      */
@@ -119,8 +119,8 @@ fn_fail:                      \
       MPIU_ERR_##CHKANDJUMP4(_ret<0,                            \
                            mpi_errno,                           \
                            MPI_ERR_OTHER,                       \
-                           "**sfi_"#STR,                        \
-                           "**sfi_"#STR" %s %d %s %s",          \
+                           "**ofi_"#STR,                        \
+                           "**ofi_"#STR" %s %d %s %s",          \
                            __SHORT_FILE__,                      \
                            __LINE__,                            \
                            FCNAME,                              \
@@ -134,8 +134,8 @@ fn_fail:                      \
       MPIU_ERR_##CHKANDJUMP4(pmi_errno!=PMI_SUCCESS,            \
                            mpi_errno,                           \
                            MPI_ERR_OTHER,                       \
-                           "**sfi_"#STR,                        \
-                           "**sfi_"#STR" %s %d %s %s",          \
+                           "**ofi_"#STR,                        \
+                           "**ofi_"#STR" %s %d %s %s",          \
                            __SHORT_FILE__,                      \
                            __LINE__,                            \
                            FCNAME,                              \
@@ -152,7 +152,7 @@ fn_fail:                      \
 #define VC_READY_CHECK(vc)                      \
 ({                                              \
   if (1 != VC_SFI(vc)->ready) {                 \
-    MPI_RC(MPID_nem_sfi_vc_connect(vc));        \
+    MPI_RC(MPID_nem_ofi_vc_connect(vc));        \
   }                                             \
 })
 
@@ -202,19 +202,19 @@ fn_fail:                      \
 /* ******************************** */
 /* Request manipulation inlines     */
 /* ******************************** */
-static inline void MPID_nem_sfi_init_req(MPID_Request * req)
+static inline void MPID_nem_ofi_init_req(MPID_Request * req)
 {
-    memset(REQ_SFI(req), 0, sizeof(MPID_nem_sfi_req_t));
+    memset(REQ_SFI(req), 0, sizeof(MPID_nem_ofi_req_t));
 }
 
-static inline int MPID_nem_sfi_create_req(MPID_Request ** request, int refcnt)
+static inline int MPID_nem_ofi_create_req(MPID_Request ** request, int refcnt)
 {
     int mpi_errno = MPI_SUCCESS;
     MPID_Request *req;
     req = MPID_Request_create();
     MPIU_Assert(req);
     MPIU_Object_set_ref(req, refcnt);
-    MPID_nem_sfi_init_req(req);
+    MPID_nem_ofi_init_req(req);
     *request = req;
     return mpi_errno;
 }
@@ -285,38 +285,38 @@ static inline int get_port(uint64_t match_bits)
 /* ************************************************************************** */
 /* MPICH Comm Override and Netmod functions                                   */
 /* ************************************************************************** */
-int MPID_nem_sfi_recv_posted(struct MPIDI_VC *vc, struct MPID_Request *req);
-int MPID_nem_sfi_send(struct MPIDI_VC *vc, const void *buf, int count,
+int MPID_nem_ofi_recv_posted(struct MPIDI_VC *vc, struct MPID_Request *req);
+int MPID_nem_ofi_send(struct MPIDI_VC *vc, const void *buf, int count,
                       MPI_Datatype datatype, int dest, int tag, MPID_Comm * comm,
                       int context_offset, struct MPID_Request **request);
-int MPID_nem_sfi_isend(struct MPIDI_VC *vc, const void *buf, int count,
+int MPID_nem_ofi_isend(struct MPIDI_VC *vc, const void *buf, int count,
                        MPI_Datatype datatype, int dest, int tag, MPID_Comm * comm,
                        int context_offset, struct MPID_Request **request);
-int MPID_nem_sfi_ssend(struct MPIDI_VC *vc, const void *buf, int count,
+int MPID_nem_ofi_ssend(struct MPIDI_VC *vc, const void *buf, int count,
                        MPI_Datatype datatype, int dest, int tag, MPID_Comm * comm,
                        int context_offset, struct MPID_Request **request);
-int MPID_nem_sfi_issend(struct MPIDI_VC *vc, const void *buf, int count,
+int MPID_nem_ofi_issend(struct MPIDI_VC *vc, const void *buf, int count,
                         MPI_Datatype datatype, int dest, int tag, MPID_Comm * comm,
                         int context_offset, struct MPID_Request **request);
-int MPID_nem_sfi_cancel_send(struct MPIDI_VC *vc, struct MPID_Request *sreq);
-int MPID_nem_sfi_cancel_recv(struct MPIDI_VC *vc, struct MPID_Request *rreq);
-int MPID_nem_sfi_iprobe(struct MPIDI_VC *vc, int source, int tag, MPID_Comm * comm,
+int MPID_nem_ofi_cancel_send(struct MPIDI_VC *vc, struct MPID_Request *sreq);
+int MPID_nem_ofi_cancel_recv(struct MPIDI_VC *vc, struct MPID_Request *rreq);
+int MPID_nem_ofi_iprobe(struct MPIDI_VC *vc, int source, int tag, MPID_Comm * comm,
                         int context_offset, int *flag, MPI_Status * status);
-int MPID_nem_sfi_improbe(struct MPIDI_VC *vc, int source, int tag, MPID_Comm * comm,
+int MPID_nem_ofi_improbe(struct MPIDI_VC *vc, int source, int tag, MPID_Comm * comm,
                          int context_offset, int *flag, MPID_Request ** message,
                          MPI_Status * status);
-int MPID_nem_sfi_anysource_iprobe(int tag, MPID_Comm * comm, int context_offset,
+int MPID_nem_ofi_anysource_iprobe(int tag, MPID_Comm * comm, int context_offset,
                                   int *flag, MPI_Status * status);
-int MPID_nem_sfi_anysource_improbe(int tag, MPID_Comm * comm, int context_offset,
+int MPID_nem_ofi_anysource_improbe(int tag, MPID_Comm * comm, int context_offset,
                                    int *flag, MPID_Request ** message, MPI_Status * status);
-void MPID_nem_sfi_anysource_posted(MPID_Request * rreq);
-int MPID_nem_sfi_anysource_matched(MPID_Request * rreq);
-int MPID_nem_sfi_send_data(cq_tagged_entry_t * wc, MPID_Request * sreq);
-int MPID_nem_sfi_SendNoncontig(MPIDI_VC_t * vc, MPID_Request * sreq,
+void MPID_nem_ofi_anysource_posted(MPID_Request * rreq);
+int MPID_nem_ofi_anysource_matched(MPID_Request * rreq);
+int MPID_nem_ofi_send_data(cq_tagged_entry_t * wc, MPID_Request * sreq);
+int MPID_nem_ofi_SendNoncontig(MPIDI_VC_t * vc, MPID_Request * sreq,
                                void *hdr, MPIDI_msg_sz_t hdr_sz);
-int MPID_nem_sfi_iStartContigMsg(MPIDI_VC_t * vc, void *hdr, MPIDI_msg_sz_t hdr_sz,
+int MPID_nem_ofi_iStartContigMsg(MPIDI_VC_t * vc, void *hdr, MPIDI_msg_sz_t hdr_sz,
                                  void *data, MPIDI_msg_sz_t data_sz, MPID_Request ** sreq_ptr);
-int MPID_nem_sfi_iSendContig(MPIDI_VC_t * vc, MPID_Request * sreq, void *hdr,
+int MPID_nem_ofi_iSendContig(MPIDI_VC_t * vc, MPID_Request * sreq, void *hdr,
                              MPIDI_msg_sz_t hdr_sz, void *data, MPIDI_msg_sz_t data_sz);
 
 /* ************************************************************************** */
@@ -324,19 +324,19 @@ int MPID_nem_sfi_iSendContig(MPIDI_VC_t * vc, MPID_Request * sreq, void *hdr,
 /* ************************************************************************** */
 #define MPID_NONBLOCKING_POLL 0
 #define MPID_BLOCKING_POLL 1
-int MPID_nem_sfi_init(MPIDI_PG_t * pg_p, int pg_rank, char **bc_val_p, int *val_max_sz_p);
-int MPID_nem_sfi_finalize(void);
-int MPID_nem_sfi_vc_init(MPIDI_VC_t * vc);
-int MPID_nem_sfi_get_business_card(int my_rank, char **bc_val_p, int *val_max_sz_p);
-int MPID_nem_sfi_poll(int in_blocking_poll);
-int MPID_nem_sfi_vc_terminate(MPIDI_VC_t * vc);
-int MPID_nem_sfi_vc_connect(MPIDI_VC_t * vc);
-int MPID_nem_sfi_connect_to_root(const char *business_card, MPIDI_VC_t * new_vc);
-int MPID_nem_sfi_vc_destroy(MPIDI_VC_t * vc);
-int MPID_nem_sfi_cm_init(MPIDI_PG_t * pg_p, int pg_rank);
-int MPID_nem_sfi_cm_finalize();
+int MPID_nem_ofi_init(MPIDI_PG_t * pg_p, int pg_rank, char **bc_val_p, int *val_max_sz_p);
+int MPID_nem_ofi_finalize(void);
+int MPID_nem_ofi_vc_init(MPIDI_VC_t * vc);
+int MPID_nem_ofi_get_business_card(int my_rank, char **bc_val_p, int *val_max_sz_p);
+int MPID_nem_ofi_poll(int in_blocking_poll);
+int MPID_nem_ofi_vc_terminate(MPIDI_VC_t * vc);
+int MPID_nem_ofi_vc_connect(MPIDI_VC_t * vc);
+int MPID_nem_ofi_connect_to_root(const char *business_card, MPIDI_VC_t * new_vc);
+int MPID_nem_ofi_vc_destroy(MPIDI_VC_t * vc);
+int MPID_nem_ofi_cm_init(MPIDI_PG_t * pg_p, int pg_rank);
+int MPID_nem_ofi_cm_finalize();
 
-extern MPID_nem_sfi_global_t gl_data;
+extern MPID_nem_ofi_global_t gl_data;
 extern MPIDI_Comm_ops_t _g_comm_ops;
 
 #endif
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_init.c b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_init.c
similarity index 92%
rename from src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_init.c
rename to src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_init.c
index 586e522..cd9e7c7 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_init.c
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_init.c
@@ -7,14 +7,14 @@
  *  to Argonne National Laboratory subject to Software Grant and Corporate
  *  Contributor License Agreement dated February 8, 2012.
  */
-#include "sfi_impl.h"
+#include "ofi_impl.h"
 
 static inline int dump_and_choose_providers(info_t * prov, info_t ** prov_use);
 static inline int compile_time_checking();
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_init)
-int MPID_nem_sfi_init(MPIDI_PG_t * pg_p, int pg_rank, char **bc_val_p, int *val_max_sz_p)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_init)
+int MPID_nem_ofi_init(MPIDI_PG_t * pg_p, int pg_rank, char **bc_val_p, int *val_max_sz_p)
 {
     int ret, fi_version, i, len, pmi_errno;
     int mpi_errno = MPI_SUCCESS;
@@ -92,7 +92,7 @@ int MPID_nem_sfi_init(MPIDI_PG_t * pg_p, int pg_rank, char **bc_val_p, int *val_
                      &prov_tagged),     /* Out: List of providers that match hints   */
           getinfo);
     MPIU_ERR_CHKANDJUMP4(prov_tagged == NULL, mpi_errno, MPI_ERR_OTHER,
-                         "**sfi_getinfo", "**sfi_getinfo %s %d %s %s",
+                         "**ofi_getinfo", "**ofi_getinfo %s %d %s %s",
                          __SHORT_FILE__, __LINE__, FCNAME, "No tag matching provider found");
     /* ------------------------------------------------------------------------ */
     /* Open fabric                                                              */
@@ -197,7 +197,7 @@ int MPID_nem_sfi_init(MPIDI_PG_t * pg_p, int pg_rank, char **bc_val_p, int *val_
     /* Get our business card            */
     /* -------------------------------- */
     my_bc = *bc_val_p;
-    MPI_RC(MPID_nem_sfi_get_business_card(pg_rank, bc_val_p, val_max_sz_p));
+    MPI_RC(MPID_nem_ofi_get_business_card(pg_rank, bc_val_p, val_max_sz_p));
 
     /* -------------------------------- */
     /* Publish the business card        */
@@ -273,7 +273,7 @@ int MPID_nem_sfi_init(MPIDI_PG_t * pg_p, int pg_rank, char **bc_val_p, int *val_
     /* required, like connection management and      */
     /* startcontig messages                          */
     /* --------------------------------------------- */
-    MPI_RC(MPID_nem_sfi_cm_init(pg_p, pg_rank));
+    MPI_RC(MPID_nem_ofi_cm_init(pg_p, pg_rank));
   fn_exit:
     if (fi_addrs)
         MPIU_Free(fi_addrs);
@@ -285,8 +285,8 @@ int MPID_nem_sfi_init(MPIDI_PG_t * pg_p, int pg_rank, char **bc_val_p, int *val_
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_finalize)
-int MPID_nem_sfi_finalize(void)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_finalize)
+int MPID_nem_ofi_finalize(void)
 {
     int mpi_errno = MPI_SUCCESS;
     int ret = 0;
@@ -303,7 +303,7 @@ int MPID_nem_sfi_finalize(void)
     /* Cancels any persistent/global requests and    */
     /* frees any resources from cm_init()            */
     /* --------------------------------------------- */
-    MPI_RC(MPID_nem_sfi_cm_finalize());
+    MPI_RC(MPID_nem_ofi_cm_finalize());
 
     FI_RC(fi_close((fid_t) gl_data.mr), mrclose);
     FI_RC(fi_close((fid_t) gl_data.av), avclose);
@@ -316,8 +316,8 @@ int MPID_nem_sfi_finalize(void)
 
 static inline int compile_time_checking()
 {
-    SFI_COMPILE_TIME_ASSERT(sizeof(MPID_nem_sfi_vc_t) <= MPID_NEM_VC_NETMOD_AREA_LEN);
-    SFI_COMPILE_TIME_ASSERT(sizeof(MPID_nem_sfi_req_t) <= MPID_NEM_REQ_NETMOD_AREA_LEN);
+    SFI_COMPILE_TIME_ASSERT(sizeof(MPID_nem_ofi_vc_t) <= MPID_NEM_VC_NETMOD_AREA_LEN);
+    SFI_COMPILE_TIME_ASSERT(sizeof(MPID_nem_ofi_req_t) <= MPID_NEM_REQ_NETMOD_AREA_LEN);
     SFI_COMPILE_TIME_ASSERT(sizeof(iovec_t) == sizeof(MPID_IOV));
     MPIU_Assert(((void *) &(((iovec_t *) 0)->iov_base)) ==
                 ((void *) &(((MPID_IOV *) 0)->MPID_IOV_BUF)));
@@ -333,28 +333,28 @@ static inline int compile_time_checking()
     /* likely needs a MPIU_ERR_REGISTER macro                                   */
     /* ------------------------------------------------------------------------ */
 #if 0
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_avmap", "**sfi_avmap %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_tsend", "**sfi_tsend %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_trecv", "**sfi_trecv %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_getinfo", "**sfi_getinfo %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_openep", "**sfi_openep %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_openfabric", "**sfi_openfabric %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_opendomain", "**sfi_opendomain %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_opencq", "**sfi_opencq %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_avopen", "**sfi_avopen %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_bind", "**sfi_bind %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_ep_enable", "**sfi_ep_enable %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_getname", "**sfi_getname %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_avclose", "**sfi_avclose %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_epclose", "**sfi_epclose %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_cqclose", "**sfi_cqclose %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_fabricclose", "**sfi_fabricclose %s %d %s %s", a, b, a,
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_avmap", "**ofi_avmap %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_tsend", "**ofi_tsend %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_trecv", "**ofi_trecv %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_getinfo", "**ofi_getinfo %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_openep", "**ofi_openep %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_openfabric", "**ofi_openfabric %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_opendomain", "**ofi_opendomain %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_opencq", "**ofi_opencq %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_avopen", "**ofi_avopen %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_bind", "**ofi_bind %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_ep_enable", "**ofi_ep_enable %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_getname", "**ofi_getname %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_avclose", "**ofi_avclose %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_epclose", "**ofi_epclose %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_cqclose", "**ofi_cqclose %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_fabricclose", "**ofi_fabricclose %s %d %s %s", a, b, a,
                   a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_domainclose", "**sfi_domainclose %s %d %s %s", a, b, a,
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_domainclose", "**ofi_domainclose %s %d %s %s", a, b, a,
                   a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_tsearch", "**sfi_tsearch %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_poll", "**sfi_poll %s %d %s %s", a, b, a, a);
-    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**sfi_cancel", "**sfi_cancel %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_tsearch", "**ofi_tsearch %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_poll", "**ofi_poll %s %d %s %s", a, b, a, a);
+    MPIU_ERR_SET2(e, MPI_ERR_OTHER, "**ofi_cancel", "**ofi_cancel %s %d %s %s", a, b, a, a);
 #endif
     return 0;
 }
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_progress.c b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_progress.c
similarity index 89%
rename from src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_progress.c
rename to src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_progress.c
index fdb1bbf..ebe1fa2 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_progress.c
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_progress.c
@@ -7,7 +7,7 @@
  *  to Argonne National Laboratory subject to Software Grant and Corporate
  *  Contributor License Agreement dated February 8, 2012.
  */
-#include "sfi_impl.h"
+#include "ofi_impl.h"
 
 #define TSEARCH_INIT      0
 #define TSEARCH_NOT_FOUND 1
@@ -16,9 +16,9 @@
 /* ------------------------------------------------------------------------ */
 /* This routine looks up the request that contains a context object         */
 /* ------------------------------------------------------------------------ */
-static inline MPID_Request *context_to_req(void *sfi_context)
+static inline MPID_Request *context_to_req(void *ofi_context)
 {
-    return (MPID_Request *) container_of(sfi_context, MPID_Request, ch.netmod_area.padding);
+    return (MPID_Request *) container_of(ofi_context, MPID_Request, ch.netmod_area.padding);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -64,8 +64,8 @@ static int tsearch_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_iprobe_impl)
-int MPID_nem_sfi_iprobe_impl(struct MPIDI_VC *vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_iprobe_impl)
+int MPID_nem_ofi_iprobe_impl(struct MPIDI_VC *vc,
                              int source,
                              int tag,
                              MPID_Comm * comm,
@@ -110,7 +110,7 @@ int MPID_nem_sfi_iprobe_impl(struct MPIDI_VC *vc,
                      0, /* Flags                */
                      &remote_proc,      /* Remote Address       */
                      &len,      /* Out:  incoming msglen */
-                     &(REQ_SFI(rreq)->sfi_context));    /* Nonblocking context  */
+                     &(REQ_SFI(rreq)->ofi_context));    /* Nonblocking context  */
     if (ret == -FI_ENOMSG) {
         *flag = 0;
         goto fn_exit;
@@ -123,11 +123,11 @@ int MPID_nem_sfi_iprobe_impl(struct MPIDI_VC *vc,
     }
     else {
         MPIU_ERR_CHKANDJUMP4((ret < 0), mpi_errno, MPI_ERR_OTHER,
-                             "**sfi_tsearch", "**sfi_tsearch %s %d %s %s",
+                             "**ofi_tsearch", "**ofi_tsearch %s %d %s %s",
                              __SHORT_FILE__, __LINE__, FCNAME, fi_strerror(-ret));
     }
     while (TSEARCH_INIT == REQ_SFI(rreq)->match_state)
-        MPID_nem_sfi_poll(MPID_BLOCKING_POLL);
+        MPID_nem_ofi_poll(MPID_BLOCKING_POLL);
 
     if (REQ_SFI(rreq)->match_state == TSEARCH_NOT_FOUND) {
         if (rreq_ptr) {
@@ -144,22 +144,22 @@ int MPID_nem_sfi_iprobe_impl(struct MPIDI_VC *vc,
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_iprobe)
-int MPID_nem_sfi_iprobe(struct MPIDI_VC *vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_iprobe)
+int MPID_nem_ofi_iprobe(struct MPIDI_VC *vc,
                         int source,
                         int tag,
                         MPID_Comm * comm, int context_offset, int *flag, MPI_Status * status)
 {
     int rc;
     BEGIN_FUNC(FCNAME);
-    rc = MPID_nem_sfi_iprobe_impl(vc, source, tag, comm, context_offset, flag, status, NULL);
+    rc = MPID_nem_ofi_iprobe_impl(vc, source, tag, comm, context_offset, flag, status, NULL);
     END_FUNC(FCNAME);
     return rc;
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_improbe)
-int MPID_nem_sfi_improbe(struct MPIDI_VC *vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_improbe)
+int MPID_nem_ofi_improbe(struct MPIDI_VC *vc,
                          int source,
                          int tag,
                          MPID_Comm * comm,
@@ -169,7 +169,7 @@ int MPID_nem_sfi_improbe(struct MPIDI_VC *vc,
     int old_error = status->MPI_ERROR;
     int s;
     BEGIN_FUNC(FCNAME);
-    s = MPID_nem_sfi_iprobe_impl(vc, source, tag, comm, context_offset, flag, status, message);
+    s = MPID_nem_ofi_iprobe_impl(vc, source, tag, comm, context_offset, flag, status, message);
     if (flag && *flag) {
         status->MPI_ERROR = old_error;
         (*message)->kind = MPID_REQUEST_MPROBE;
@@ -179,36 +179,36 @@ int MPID_nem_sfi_improbe(struct MPIDI_VC *vc,
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_anysource_iprobe)
-int MPID_nem_sfi_anysource_iprobe(int tag,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_anysource_iprobe)
+int MPID_nem_ofi_anysource_iprobe(int tag,
                                   MPID_Comm * comm,
                                   int context_offset, int *flag, MPI_Status * status)
 {
     int rc;
     BEGIN_FUNC(FCNAME);
-    rc = MPID_nem_sfi_iprobe(NULL, MPI_ANY_SOURCE, tag, comm, context_offset, flag, status);
+    rc = MPID_nem_ofi_iprobe(NULL, MPI_ANY_SOURCE, tag, comm, context_offset, flag, status);
     END_FUNC(FCNAME);
     return rc;
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_anysource_improbe)
-int MPID_nem_sfi_anysource_improbe(int tag,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_anysource_improbe)
+int MPID_nem_ofi_anysource_improbe(int tag,
                                    MPID_Comm * comm,
                                    int context_offset,
                                    int *flag, MPID_Request ** message, MPI_Status * status)
 {
     int rc;
     BEGIN_FUNC(FCNAME);
-    rc = MPID_nem_sfi_improbe(NULL, MPI_ANY_SOURCE, tag, comm,
+    rc = MPID_nem_ofi_improbe(NULL, MPI_ANY_SOURCE, tag, comm,
                               context_offset, flag, message, status);
     END_FUNC(FCNAME);
     return rc;
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_poll)
-int MPID_nem_sfi_poll(int in_blocking_poll)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_poll)
+int MPID_nem_ofi_poll(int in_blocking_poll)
 {
     int complete = 0, mpi_errno = MPI_SUCCESS;
     ssize_t ret;
@@ -281,8 +281,8 @@ int MPID_nem_sfi_poll(int in_blocking_poll)
                 }
             }
             else {
-                MPIU_ERR_CHKANDJUMP4(1, mpi_errno, MPI_ERR_OTHER, "**sfi_poll",
-                                     "**sfi_poll %s %d %s %s", __SHORT_FILE__,
+                MPIU_ERR_CHKANDJUMP4(1, mpi_errno, MPI_ERR_OTHER, "**ofi_poll",
+                                     "**ofi_poll %s %d %s %s", __SHORT_FILE__,
                                      __LINE__, FCNAME, fi_strerror(-ret));
             }
         }
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_tagged.c b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_tagged.c
similarity index 86%
rename from src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_tagged.c
rename to src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_tagged.c
index 237c735..89affd2 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_tagged.c
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_tagged.c
@@ -7,7 +7,7 @@
  *  to Argonne National Laboratory subject to Software Grant and Corporate
  *  Contributor License Agreement dated February 8, 2012.
  */
-#include "sfi_impl.h"
+#include "ofi_impl.h"
 
 #define MPID_NORMAL_SEND 0
 
@@ -15,8 +15,8 @@
 /* Receive callback called after sending a syncronous send acknowledgement. */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_sync_recv_callback)
-static inline int MPID_nem_sfi_sync_recv_callback(cq_tagged_entry_t * wc ATTRIBUTE((unused)),
+#define FCNAME DECL_FUNC(MPID_nem_ofi_sync_recv_callback)
+static inline int MPID_nem_ofi_sync_recv_callback(cq_tagged_entry_t * wc ATTRIBUTE((unused)),
                                                   MPID_Request * rreq)
 {
     int mpi_errno = MPI_SUCCESS;
@@ -36,8 +36,8 @@ static inline int MPID_nem_sfi_sync_recv_callback(cq_tagged_entry_t * wc ATTRIBU
 /* Free any temporary/pack buffers and complete the send request            */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_send_callback)
-static inline int MPID_nem_sfi_send_callback(cq_tagged_entry_t * wc ATTRIBUTE((unused)),
+#define FCNAME DECL_FUNC(MPID_nem_ofi_send_callback)
+static inline int MPID_nem_ofi_send_callback(cq_tagged_entry_t * wc ATTRIBUTE((unused)),
                                              MPID_Request * sreq)
 {
     int mpi_errno = MPI_SUCCESS;
@@ -54,8 +54,8 @@ static inline int MPID_nem_sfi_send_callback(cq_tagged_entry_t * wc ATTRIBUTE((u
 /* Handle an incoming receive completion event                              */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_recv_callback)
-static inline int MPID_nem_sfi_recv_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_recv_callback)
+static inline int MPID_nem_ofi_recv_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
 {
     int err0, err1, src, mpi_errno = MPI_SUCCESS;
     uint64_t ssend_bits;
@@ -99,17 +99,17 @@ static inline int MPID_nem_sfi_recv_callback(cq_tagged_entry_t * wc, MPID_Reques
         }
         ssend_bits = init_sendtag(rreq->dev.match.parts.context_id,
                                   rreq->comm->rank, rreq->status.MPI_TAG, MPID_SYNC_SEND_ACK);
-        MPID_nem_sfi_create_req(&sync_req, 1);
+        MPID_nem_ofi_create_req(&sync_req, 1);
         sync_req->dev.OnDataAvail = NULL;
         sync_req->dev.next = NULL;
-        REQ_SFI(sync_req)->event_callback = MPID_nem_sfi_sync_recv_callback;
+        REQ_SFI(sync_req)->event_callback = MPID_nem_ofi_sync_recv_callback;
         REQ_SFI(sync_req)->parent = rreq;
         FI_RC(fi_tsend(gl_data.endpoint,
                          NULL,
                          0,
                          gl_data.mr,
                          VC_SFI(vc)->direct_addr,
-                         ssend_bits, &(REQ_SFI(sync_req)->sfi_context)), tsend);
+                         ssend_bits, &(REQ_SFI(sync_req)->ofi_context)), tsend);
     }
     else {
         /* ---------------------------------------------------- */
@@ -147,10 +147,10 @@ static inline int do_isend(struct MPIDI_VC *vc,
     /* ---------------------------------------------------- */
     /* Create the MPI request                               */
     /* ---------------------------------------------------- */
-    MPID_nem_sfi_create_req(&sreq, 2);
+    MPID_nem_ofi_create_req(&sreq, 2);
     sreq->kind = MPID_REQUEST_SEND;
     sreq->dev.OnDataAvail = NULL;
-    REQ_SFI(sreq)->event_callback = MPID_nem_sfi_send_callback;
+    REQ_SFI(sreq)->event_callback = MPID_nem_ofi_send_callback;
     REQ_SFI(sreq)->vc = vc;
 
     /* ---------------------------------------------------- */
@@ -178,10 +178,10 @@ static inline int do_isend(struct MPIDI_VC *vc,
         /* ---------------------------------------------------- */
         int c = 1;
         MPID_cc_incr(sreq->cc_ptr, &c);
-        MPID_nem_sfi_create_req(&sync_req, 1);
+        MPID_nem_ofi_create_req(&sync_req, 1);
         sync_req->dev.OnDataAvail = NULL;
         sync_req->dev.next = NULL;
-        REQ_SFI(sync_req)->event_callback = MPID_nem_sfi_sync_recv_callback;
+        REQ_SFI(sync_req)->event_callback = MPID_nem_ofi_sync_recv_callback;
         REQ_SFI(sync_req)->parent = sreq;
         ssend_match = init_recvtag(&ssend_mask, comm->context_id + context_offset, dest, tag);
         ssend_match |= MPID_SYNC_SEND_ACK;
@@ -192,7 +192,7 @@ static inline int do_isend(struct MPIDI_VC *vc,
                            VC_SFI(vc)->direct_addr,     /* remote proc */
                            ssend_match, /* match bits  */
                            0ULL,        /* mask bits   */
-                           &(REQ_SFI(sync_req)->sfi_context)), trecv);
+                           &(REQ_SFI(sync_req)->ofi_context)), trecv);
     }
     FI_RC(fi_tsend(gl_data.endpoint,  /* Endpoint                       */
                      send_buffer,       /* Send buffer(packed or user)    */
@@ -200,14 +200,14 @@ static inline int do_isend(struct MPIDI_VC *vc,
                      gl_data.mr,        /* Dynamic memory region          */
                      VC_SFI(vc)->direct_addr,   /* Use the address of this VC     */
                      match_bits,        /* Match bits                     */
-                     &(REQ_SFI(sreq)->sfi_context)), tsend);
+                     &(REQ_SFI(sreq)->ofi_context)), tsend);
     *request = sreq;
     END_FUNC_RC(FCNAME);
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_recv_posted)
-int MPID_nem_sfi_recv_posted(struct MPIDI_VC *vc, struct MPID_Request *rreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_recv_posted)
+int MPID_nem_ofi_recv_posted(struct MPIDI_VC *vc, struct MPID_Request *rreq)
 {
     int mpi_errno = MPI_SUCCESS, dt_contig, src, tag;
     uint64_t match_bits = 0, mask_bits = 0;
@@ -222,8 +222,8 @@ int MPID_nem_sfi_recv_posted(struct MPIDI_VC *vc, struct MPID_Request *rreq)
     /* ------------------------ */
     /* Initialize the request   */
     /* ------------------------ */
-    MPID_nem_sfi_init_req(rreq);
-    REQ_SFI(rreq)->event_callback = MPID_nem_sfi_recv_callback;
+    MPID_nem_ofi_init_req(rreq);
+    REQ_SFI(rreq)->event_callback = MPID_nem_ofi_recv_callback;
     REQ_SFI(rreq)->vc = vc;
 
     /* ---------------------------------------------------- */
@@ -255,14 +255,14 @@ int MPID_nem_sfi_recv_posted(struct MPIDI_VC *vc, struct MPID_Request *rreq)
                        data_sz,
                        gl_data.mr,
                        remote_proc,
-                       match_bits, mask_bits, &(REQ_SFI(rreq)->sfi_context)), trecv);
-    MPID_nem_sfi_poll(MPID_NONBLOCKING_POLL);
+                       match_bits, mask_bits, &(REQ_SFI(rreq)->ofi_context)), trecv);
+    MPID_nem_ofi_poll(MPID_NONBLOCKING_POLL);
     END_FUNC_RC(FCNAME);
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_send)
-int MPID_nem_sfi_send(struct MPIDI_VC *vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_send)
+int MPID_nem_ofi_send(struct MPIDI_VC *vc,
                       const void *buf,
                       int count,
                       MPI_Datatype datatype,
@@ -279,8 +279,8 @@ int MPID_nem_sfi_send(struct MPIDI_VC *vc,
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_isend)
-int MPID_nem_sfi_isend(struct MPIDI_VC *vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_isend)
+int MPID_nem_ofi_isend(struct MPIDI_VC *vc,
                        const void *buf,
                        int count,
                        MPI_Datatype datatype,
@@ -296,8 +296,8 @@ int MPID_nem_sfi_isend(struct MPIDI_VC *vc,
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_ssend)
-int MPID_nem_sfi_ssend(struct MPIDI_VC *vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_ssend)
+int MPID_nem_ofi_ssend(struct MPIDI_VC *vc,
                        const void *buf,
                        int count,
                        MPI_Datatype datatype,
@@ -313,8 +313,8 @@ int MPID_nem_sfi_ssend(struct MPIDI_VC *vc,
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_issend)
-int MPID_nem_sfi_issend(struct MPIDI_VC *vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_issend)
+int MPID_nem_ofi_issend(struct MPIDI_VC *vc,
                         const void *buf,
                         int count,
                         MPI_Datatype datatype,
@@ -335,9 +335,9 @@ int MPID_nem_sfi_issend(struct MPIDI_VC *vc,
   int mpi_errno = MPI_SUCCESS;                          \
   int ret;                                              \
   BEGIN_FUNC(FCNAME);                                   \
-  MPID_nem_sfi_poll(MPID_NONBLOCKING_POLL);             \
+  MPID_nem_ofi_poll(MPID_NONBLOCKING_POLL);             \
   ret = fi_cancel((fid_t)gl_data.endpoint,              \
-                  &(REQ_SFI(req)->sfi_context));        \
+                  &(REQ_SFI(req)->ofi_context));        \
   if (ret == 0) {                                        \
     MPIR_STATUS_SET_CANCEL_BIT(req->status, TRUE);      \
   } else {                                              \
@@ -348,33 +348,33 @@ int MPID_nem_sfi_issend(struct MPIDI_VC *vc,
 })
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_cancel_send)
-int MPID_nem_sfi_cancel_send(struct MPIDI_VC *vc ATTRIBUTE((unused)), struct MPID_Request *sreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_cancel_send)
+int MPID_nem_ofi_cancel_send(struct MPIDI_VC *vc ATTRIBUTE((unused)), struct MPID_Request *sreq)
 {
     DO_CANCEL(sreq);
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_cancel_recv)
-int MPID_nem_sfi_cancel_recv(struct MPIDI_VC *vc ATTRIBUTE((unused)), struct MPID_Request *rreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_cancel_recv)
+int MPID_nem_ofi_cancel_recv(struct MPIDI_VC *vc ATTRIBUTE((unused)), struct MPID_Request *rreq)
 {
     DO_CANCEL(rreq);
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_anysource_posted)
-void MPID_nem_sfi_anysource_posted(MPID_Request * rreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_anysource_posted)
+void MPID_nem_ofi_anysource_posted(MPID_Request * rreq)
 {
     int mpi_errno = MPI_SUCCESS;
     BEGIN_FUNC(FCNAME);
-    mpi_errno = MPID_nem_sfi_recv_posted(NULL, rreq);
+    mpi_errno = MPID_nem_ofi_recv_posted(NULL, rreq);
     MPIU_Assert(mpi_errno == MPI_SUCCESS);
     END_FUNC(FCNAME);
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_anysource_matched)
-int MPID_nem_sfi_anysource_matched(MPID_Request * rreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_anysource_matched)
+int MPID_nem_ofi_anysource_matched(MPID_Request * rreq)
 {
     int mpi_errno = FALSE;
     int ret;
@@ -384,7 +384,7 @@ int MPID_nem_sfi_anysource_matched(MPID_Request * rreq)
     /* source request on another device.  We have the chance */
     /* to cancel this shared request if it has been posted   */
     /* ----------------------------------------------------- */
-    ret = fi_cancel((fid_t) gl_data.endpoint, &(REQ_SFI(rreq)->sfi_context));
+    ret = fi_cancel((fid_t) gl_data.endpoint, &(REQ_SFI(rreq)->ofi_context));
     if (ret == 0) {
         /* --------------------------------------------------- */
         /* Request cancelled:  cancel and complete the request */
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/subconfigure.m4 b/src/mpid/ch3/channels/nemesis/netmod/ofi/subconfigure.m4
similarity index 71%
rename from src/mpid/ch3/channels/nemesis/netmod/sfi/subconfigure.m4
rename to src/mpid/ch3/channels/nemesis/netmod/ofi/subconfigure.m4
index 361f7d0..cb6b35c 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/subconfigure.m4
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/subconfigure.m4
@@ -4,18 +4,18 @@ dnl MPICH_SUBCFG_AFTER=src/mpid/ch3/channels/nemesis
 AC_DEFUN([PAC_SUBCFG_PREREQ_]PAC_SUBCFG_AUTO_SUFFIX,[
     AM_COND_IF([BUILD_CH3_NEMESIS],[
         for net in $nemesis_networks ; do
-            AS_CASE([$net],[sfi],[build_nemesis_netmod_sfi=yes])
+            AS_CASE([$net],[ofi],[build_nemesis_netmod_ofi=yes])
         done
     ])
-    AM_CONDITIONAL([BUILD_NEMESIS_NETMOD_SFI],[test "X$build_nemesis_netmod_sfi" = "Xyes"])
+    AM_CONDITIONAL([BUILD_NEMESIS_NETMOD_SFI],[test "X$build_nemesis_netmod_ofi" = "Xyes"])
 ])dnl
 
 AC_DEFUN([PAC_SUBCFG_BODY_]PAC_SUBCFG_AUTO_SUFFIX,[
 AM_COND_IF([BUILD_NEMESIS_NETMOD_SFI],[
-    AC_MSG_NOTICE([RUNNING CONFIGURE FOR ch3:nemesis:sfi])
+    AC_MSG_NOTICE([RUNNING CONFIGURE FOR ch3:nemesis:ofi])
 
-    PAC_SET_HEADER_LIB_PATH(sfi)
-    PAC_CHECK_HEADER_LIB_FATAL(sfi, rdma/fabric.h, fabric, fi_getinfo)
+    PAC_SET_HEADER_LIB_PATH(ofi)
+    PAC_CHECK_HEADER_LIB_FATAL(ofi, rdma/fabric.h, fabric, fi_getinfo)
 
     AC_DEFINE([ENABLE_COMM_OVERRIDES], 1, [define to add per-vc function pointers to override send and recv functions])
 ])dnl end AM_COND_IF(BUILD_NEMESIS_NETMOD_SFI,...)
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/Makefile.mk b/src/mpid/ch3/channels/nemesis/netmod/sfi/Makefile.mk
deleted file mode 100644
index bc3d6ef..0000000
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/Makefile.mk
+++ /dev/null
@@ -1,19 +0,0 @@
-## -*- Mode: Makefile; -*-
-## vim: set ft=automake :
-##
-## (C) 2011 by Argonne National Laboratory.
-##     See COPYRIGHT in top-level directory.
-##
-if BUILD_NEMESIS_NETMOD_SFI
-
-mpi_core_sources +=                                 		\
-    src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_init.c 	\
-    src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_cm.c	 	\
-    src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_tagged.c	\
-    src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_msg.c	 	\
-    src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_data.c	 	\
-    src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_progress.c
-
-errnames_txt_files += src/mpid/ch3/channels/nemesis/netmod/sfi/errnames.txt
-
-endif
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/errnames.txt b/src/mpid/ch3/channels/nemesis/netmod/sfi/errnames.txt
deleted file mode 100644
index 09cb0f6..0000000
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/errnames.txt
+++ /dev/null
@@ -1,42 +0,0 @@
-**sfi_avmap:SFI get address vector map failed
-**sfi_avmap %s %d %s %s:SFI address vector map failed (%s:%d:%s:%s)
-**sfi_tsend:SFI tagged sendto failed
-**sfi_tsend %s %d %s %s:SFI tagged sendto failed (%s:%d:%s:%s)
-**sfi_trecv:SFI tagged recvfrom failed
-**sfi_trecv %s %d %s %s:SFI tagged recvfrom failed (%s:%d:%s:%s)
-**sfi_getinfo:SFI getinfo() failed
-**sfi_getinfo %s %d %s %s:SFI getinfo() failed (%s:%d:%s:%s)
-**sfi_openep:SFI endpoint open failed
-**sfi_openep %s %d %s %s:SFI endpoint open failed (%s:%d:%s:%s)
-**sfi_openfabric:SFI fabric open failure
-**sfi_openfabric %s %d %s %s:SFI fabric open failed (%s:%d:%s:%s)
-**sfi_opendomain:SFI domain open failure
-**sfi_opendomain %s %d %s %s:SFI domain open failed (%s:%d:%s:%s)
-**sfi_opencq:SFI event queue create failure
-**sfi_opencq %s %d %s %s:SFI event queue create failed (%s:%d:%s:%s)
-**sfi_avopen:SFI address vector open failed
-**sfi_avopen %s %d %s %s:SFI address vector open failed (%s:%d:%s:%s)
-**sfi_bind:SFI resource bind failure
-**sfi_bind %s %d %s %s:SFI resource bind failed (%s:%d:%s:%s)
-**sfi_ep_enable:SFI endpoint enable failed
-**sfi_ep_enable %s %d %s %s:SFI endpoint enable failed (%s:%d:%s:%s)
-**sfi_getname:SFI get endpoint name failed
-**sfi_getname %s %d %s %s:SFI get endpoint name failed (%s:%d:%s:%s)
-**sfi_avclose:SFI av close failed
-**sfi_avclose %s %d %s %s:SFI av close failed (%s:%d:%s:%s)
-**sfi_epclose:SFI endpoint close failed
-**sfi_epclose %s %d %s %s:SFI endpoint close failed (%s:%d:%s:%s)
-**sfi_cqclose:SFI cq close failed
-**sfi_cqclose %s %d %s %s:SFI cq close failed (%s:%d:%s:%s)
-**sfi_mrclose:SFI mr close failed
-**sfi_mrclose %s %d %s %s:SFI mr close failed (%s:%d:%s:%s)
-**sfi_fabricclose:SFI fabric close failed
-**sfi_fabricclose %s %d %s %s:SFI fabric close failed (%s:%d:%s:%s)
-**sfi_domainclose:SFI domain close failed
-**sfi_domainclose %s %d %s %s:SFI domain close failed (%s:%d:%s:%s)
-**sfi_tsearch:SFI tsearch failed
-**sfi_tsearch %s %d %s %s:SFI tsearch failed (%s:%d:%s:%s)
-**sfi_poll:SFI poll failed
-**sfi_poll %s %d %s %s:SFI poll failed (%s:%d:%s:%s)
-**sfi_cancel:SFI cancel failed
-**sfi_cancel %s %d %s %s:SFI cancel failed (%s:%d:%s:%s)

-----------------------------------------------------------------------

Summary of changes:
 src/mpid/ch3/channels/nemesis/netmod/Makefile.mk   |    2 +-
 .../ch3/channels/nemesis/netmod/ofi/Makefile.mk    |   19 +
 .../ch3/channels/nemesis/netmod/ofi/errnames.txt   |   42 ++
 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_cm.c  |  577 ++++++++++++++++++++
 .../ch3/channels/nemesis/netmod/ofi/ofi_data.c     |   58 ++
 .../ch3/channels/nemesis/netmod/ofi/ofi_impl.h     |  342 ++++++++++++
 .../ch3/channels/nemesis/netmod/ofi/ofi_init.c     |  461 ++++++++++++++++
 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_msg.c |  237 ++++++++
 .../ch3/channels/nemesis/netmod/ofi/ofi_progress.c |  291 ++++++++++
 .../ch3/channels/nemesis/netmod/ofi/ofi_tagged.c   |  399 ++++++++++++++
 .../channels/nemesis/netmod/ofi/subconfigure.m4    |   24 +
 .../ch3/channels/nemesis/netmod/sfi/Makefile.mk    |   19 -
 .../ch3/channels/nemesis/netmod/sfi/errnames.txt   |   42 --
 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_cm.c  |  577 --------------------
 .../ch3/channels/nemesis/netmod/sfi/sfi_data.c     |   58 --
 .../ch3/channels/nemesis/netmod/sfi/sfi_impl.h     |  342 ------------
 .../ch3/channels/nemesis/netmod/sfi/sfi_init.c     |  461 ----------------
 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_msg.c |  237 --------
 .../ch3/channels/nemesis/netmod/sfi/sfi_progress.c |  291 ----------
 .../ch3/channels/nemesis/netmod/sfi/sfi_tagged.c   |  399 --------------
 .../channels/nemesis/netmod/sfi/subconfigure.m4    |   24 -
 21 files changed, 2451 insertions(+), 2451 deletions(-)
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/Makefile.mk
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/errnames.txt
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_cm.c
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_data.c
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_impl.h
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_init.c
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_msg.c
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_progress.c
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_tagged.c
 create mode 100644 src/mpid/ch3/channels/nemesis/netmod/ofi/subconfigure.m4
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/Makefile.mk
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/errnames.txt
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_cm.c
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_data.c
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_impl.h
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_init.c
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_msg.c
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_progress.c
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_tagged.c
 delete mode 100644 src/mpid/ch3/channels/nemesis/netmod/sfi/subconfigure.m4


hooks/post-receive
diff --git a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_msg.c b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_msg.c
similarity index 90%
rename from src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_msg.c
rename to src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_msg.c
index c202997..ffa3761 100644
--- a/src/mpid/ch3/channels/nemesis/netmod/sfi/sfi_msg.c
+++ b/src/mpid/ch3/channels/nemesis/netmod/ofi/ofi_msg.c
@@ -7,7 +7,7 @@
  *  to Argonne National Laboratory subject to Software Grant and Corporate
  *  Contributor License Agreement dated February 8, 2012.
  */
-#include "sfi_impl.h"
+#include "ofi_impl.h"
 
 /* ------------------------------------------------------------------------ */
 /* GET_PGID_AND_SET_MATCH macro looks up the process group to find the      */
@@ -44,7 +44,7 @@
 /* is based on a tagged rendezvous message.                                 */
 /* The rendezvous is implemented with an RTS-CTS-Data send protocol:        */
 /* CTS_POST()   |                                  |                        */
-/* RTS_SEND()   | -------------------------------> | ue_callback()(sfi_cm.c)*/
+/* RTS_SEND()   | -------------------------------> | ue_callback()(ofi_cm.c)*/
 /*              |                                  |   pack_buffer()        */
 /*              |                                  |   DATA_POST()          */
 /*              |                                  |   RTS_POST()           */
@@ -61,16 +61,16 @@
     c = 1;                                                              \
     MPID_cc_incr(sreq->cc_ptr, &c);                                     \
     MPID_cc_incr(sreq->cc_ptr, &c);                                     \
-    REQ_SFI(sreq)->event_callback   = MPID_nem_sfi_data_callback;       \
+    REQ_SFI(sreq)->event_callback   = MPID_nem_ofi_data_callback;       \
     REQ_SFI(sreq)->pack_buffer      = pack_buffer;                      \
     REQ_SFI(sreq)->pack_buffer_size = pkt_len;                          \
     REQ_SFI(sreq)->vc               = vc;                               \
     REQ_SFI(sreq)->tag              = match_bits;                       \
                                                                         \
-    MPID_nem_sfi_create_req(&cts_req, 1);                               \
+    MPID_nem_ofi_create_req(&cts_req, 1);                               \
     cts_req->dev.OnDataAvail         = NULL;                            \
     cts_req->dev.next                = NULL;                            \
-    REQ_SFI(cts_req)->event_callback = MPID_nem_sfi_cts_recv_callback;  \
+    REQ_SFI(cts_req)->event_callback = MPID_nem_ofi_cts_recv_callback;  \
     REQ_SFI(cts_req)->parent         = sreq;                            \
                                                                         \
     FI_RC(fi_trecv(gl_data.endpoint,                                \
@@ -80,14 +80,14 @@
                        VC_SFI(vc)->direct_addr,                         \
                        match_bits | MPID_MSG_CTS,                       \
                        0, /* Exact tag match, no ignore bits */         \
-                       &(REQ_SFI(cts_req)->sfi_context)),trecv);    \
+                       &(REQ_SFI(cts_req)->ofi_context)),trecv);    \
     FI_RC(fi_tsend(gl_data.endpoint,                                  \
                      &REQ_SFI(sreq)->pack_buffer_size,                  \
                      sizeof(REQ_SFI(sreq)->pack_buffer_size),           \
                      gl_data.mr,                                        \
                      VC_SFI(vc)->direct_addr,                           \
                      match_bits,                                        \
-                     &(REQ_SFI(sreq)->sfi_context)),tsend);           \
+                     &(REQ_SFI(sreq)->ofi_context)),tsend);           \
   })
 
 
@@ -97,8 +97,8 @@
 /* bulk data transfer.  On data send completion, the request can be freed   */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_data_callback)
-static int MPID_nem_sfi_data_callback(cq_tagged_entry_t * wc, MPID_Request * sreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_data_callback)
+static int MPID_nem_ofi_data_callback(cq_tagged_entry_t * wc, MPID_Request * sreq)
 {
     int complete = 0, mpi_errno = MPI_SUCCESS;
     MPIDI_VC_t *vc;
@@ -113,7 +113,7 @@ static int MPID_nem_sfi_data_callback(cq_tagged_entry_t * wc, MPID_Request * sre
                          REQ_SFI(sreq)->pack_buffer_size,
                          gl_data.mr,
                          VC_SFI(vc)->direct_addr,
-                         wc->tag | MPID_MSG_DATA, (void *) &(REQ_SFI(sreq)->sfi_context)), tsend);
+                         wc->tag | MPID_MSG_DATA, (void *) &(REQ_SFI(sreq)->ofi_context)), tsend);
     }
     if (sreq->cc == 1) {
         if (REQ_SFI(sreq)->pack_buffer)
@@ -135,16 +135,16 @@ static int MPID_nem_sfi_data_callback(cq_tagged_entry_t * wc, MPID_Request * sre
 }
 
 /* ------------------------------------------------------------------------ */
 /* Signals the CTS has been received.  Call MPID_nem_sfi_data_callback on   */
 /* the parent send request to kick off the bulk data transfer               */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_cts_recv_callback)
-static int MPID_nem_sfi_cts_recv_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
+#define FCNAME DECL_FUNC(MPID_nem_ofi_cts_recv_callback)
+static int MPID_nem_ofi_cts_recv_callback(cq_tagged_entry_t * wc, MPID_Request * rreq)
 {
     int mpi_errno = MPI_SUCCESS;
     BEGIN_FUNC(FCNAME);
-    MPI_RC(MPID_nem_sfi_data_callback(wc, REQ_SFI(rreq)->parent));
+    MPI_RC(MPID_nem_ofi_data_callback(wc, REQ_SFI(rreq)->parent));
     MPIDI_CH3U_Request_complete(rreq);
     END_FUNC_RC(FCNAME);
 }
@@ -158,8 +158,8 @@ static int MPID_nem_sfi_cts_recv_callback(cq_tagged_entry_t * wc, MPID_Request *
 /* functions over a tagged msg interface                                    */
 /* ------------------------------------------------------------------------ */
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_iSendContig)
-int MPID_nem_sfi_iSendContig(MPIDI_VC_t * vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_iSendContig)
+int MPID_nem_ofi_iSendContig(MPIDI_VC_t * vc,
                              MPID_Request * sreq,
                              void *hdr, MPIDI_msg_sz_t hdr_sz, void *data, MPIDI_msg_sz_t data_sz)
 {
@@ -170,7 +170,7 @@ int MPID_nem_sfi_iSendContig(MPIDI_VC_t * vc,
 
     BEGIN_FUNC(FCNAME);
     MPIU_Assert(hdr_sz <= (MPIDI_msg_sz_t) sizeof(MPIDI_CH3_Pkt_t));
-    MPID_nem_sfi_init_req(sreq);
+    MPID_nem_ofi_init_req(sreq);
     pkt_len = sizeof(MPIDI_CH3_Pkt_t) + data_sz;
     pack_buffer = MPIU_Malloc(pkt_len);
     MPIU_Assert(pack_buffer);
@@ -181,8 +181,8 @@ int MPID_nem_sfi_iSendContig(MPIDI_VC_t * vc,
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_SendNoncontig)
-int MPID_nem_sfi_SendNoncontig(MPIDI_VC_t * vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_SendNoncontig)
+int MPID_nem_ofi_SendNoncontig(MPIDI_VC_t * vc,
                                MPID_Request * sreq, void *hdr, MPIDI_msg_sz_t hdr_sz)
 {
     int c, pgid, pkt_len, mpi_errno = MPI_SUCCESS;
@@ -202,13 +202,13 @@ int MPID_nem_sfi_SendNoncontig(MPIDI_VC_t * vc,
     MPIU_Memcpy(pack_buffer, hdr, hdr_sz);
     MPID_Segment_pack(sreq->dev.segment_ptr, 0, &data_sz, pack_buffer + sizeof(MPIDI_CH3_Pkt_t));
     START_COMM();
-    MPID_nem_sfi_poll(MPID_NONBLOCKING_POLL);
+    MPID_nem_ofi_poll(MPID_NONBLOCKING_POLL);
     END_FUNC_RC(FCNAME);
 }
 
 #undef FCNAME
-#define FCNAME DECL_FUNC(MPID_nem_sfi_iStartContigMsg)
-int MPID_nem_sfi_iStartContigMsg(MPIDI_VC_t * vc,
+#define FCNAME DECL_FUNC(MPID_nem_ofi_iStartContigMsg)
+int MPID_nem_ofi_iStartContigMsg(MPIDI_VC_t * vc,
                                  void *hdr,
                                  MPIDI_msg_sz_t hdr_sz,
                                  void *data, MPIDI_msg_sz_t data_sz, MPID_Request ** sreq_ptr)
@@ -221,7 +221,7 @@ int MPID_nem_sfi_iStartContigMsg(MPIDI_VC_t * vc,
     BEGIN_FUNC(FCNAME);
     MPIU_Assert(hdr_sz <= (MPIDI_msg_sz_t) sizeof(MPIDI_CH3_Pkt_t));
 
-    MPID_nem_sfi_create_req(&sreq, 2);
+    MPID_nem_ofi_create_req(&sreq, 2);
     sreq->kind = MPID_REQUEST_SEND;
     sreq->dev.OnDataAvail = NULL;
     sreq->dev.next = NULL;
@@ -135,16 +135,16 @@ static int MPID_nem_sfi_data_callback(cq_tagged_entry_t * wc, MPID_Request * sre
 
 /* ------------------------------------------------------------------------ */
-/* Signals the CTS has been received.  Call MPID_nem_sfi_data_callback on   */
+/* Signals the CTS has been received.  Call MPID_nem_ofi_data_callback on   */
 /* the parent send request to kick off the bulk data transfer               */
 /* ------------------------------------------------------------------------ */
-- 
MPICH primary repository


More information about the commits mailing list